/*
   CIPE - encrypted IP over UDP tunneling

   ciped.h - prototypes for user level routines

   Copyright 1997 Olaf Titz <olaf@bigred.inka.de>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version
   2 of the License, or (at your option) any later version.
*/
/* $Id: ciped.h,v 1.2.2.1 1999/04/27 21:53:22 olaf Exp $ */

#include "cipe.h"

/* ciped.c */
extern void logd(int lev, const char *f, int d);
extern void logs(int lev, const char *f, const char *s);
extern void logerr(int lev, const char *s);

/* socks5.c */
#define S5_CONN		1
#define S5_BIND		2
#define S5_UDP		3
extern int socks5_open(struct sockaddr_in *so);
int socks5_cmd(int fd, int cmd, struct sockaddr_in *so);
